@@ -4,8 +4,8 @@ from typing import Optional, List
 
 @dataclasses.dataclass(frozen=True)
 class AugmentationConfig:
-    train: Optional[str]
-    val: Optional[str]
+    train: List[str]
+    val: List[str]
 
 
 @dataclasses.dataclass(frozen=True)
@@ -45,6 +45,9 @@ class TrainingConfig:
     task_type: str
     batch_size: int
     max_epochs: int
+    use_fp16: bool = True
+    use_swa: bool = False
+    swa_epoch_start: float = 0.9
     model: ModelConfig = None
     augmentation: AugmentationConfig = None
     lr_scheduler: LrSchedulerConfig = None
